@@ -33,6 +33,8 @@
 #include "webserver.h"
 #include "groupdav.h"
 
+extern int DisableGzip;
+
 /*
  * Given an encoded UID, translate that to an unencoded Citadel EUID and
  * then search for it in the current room.  Return a message number or -1
@@ -290,7 +292,8 @@ void groupdav_collection_list(void)
 	groupdav_common_headers();
 	hprintf("Date: %s\r\n", datestring);
 	hprintf("Content-type: text/xml\r\n");
-	hprintf("Content-encoding: identity\r\n");
+	if (DisableGzip || (!WCC->Hdr->HR.gzip_ok))	
+		hprintf("Content-encoding: identity\r\n");
 
 	begin_burst();
 
@@ -484,7 +487,8 @@ void groupdav_propfind(void)
 		groupdav_common_headers();
 		hprintf("Date: %s\r\n", datestring);
 		hprintf("Content-type: text/xml\r\n");
-		hprintf("Content-encoding: identity\r\n");
+		if (DisableGzip || (!WCC->Hdr->HR.gzip_ok))	
+			hprintf("Content-encoding: identity\r\n");
 
 		begin_burst();
 
@@ -571,7 +575,8 @@ void groupdav_propfind(void)
 		groupdav_common_headers();
 		hprintf("Date: %s\r\n", datestring);
 		hprintf("Content-type: text/xml\r\n");
-		hprintf("Content-encoding: identity\r\n");
+		if (DisableGzip || (!WCC->Hdr->HR.gzip_ok))	
+			hprintf("Content-encoding: identity\r\n");
 	
 		begin_burst();
 	
@@ -621,7 +626,8 @@ void groupdav_propfind(void)
 	groupdav_common_headers();
 	hprintf("Date: %s\r\n", datestring);
 	hprintf("Content-type: text/xml\r\n");
-	hprintf("Content-encoding: identity\r\n");
+	if (DisableGzip || (!WCC->Hdr->HR.gzip_ok))	
+		hprintf("Content-encoding: identity\r\n");
 
 	begin_burst();
 
@@ -676,7 +682,10 @@ void groupdav_propfind(void)
 
 	StrBuf_ServGetln(MsgNum);
 	if (GetServerStatus(MsgNum, NULL) == 1)
-		while (BufLen = StrBuf_ServGetln(MsgNum), strcmp(ChrPtr(MsgNum), "000"))  {
+		while (BufLen = StrBuf_ServGetln(MsgNum), 
+		       ((BufLen >= 0) && 
+			((BufLen != 3) || strcmp(ChrPtr(MsgNum), "000"))  ))
+		{
 			msgs = realloc(msgs, ++num_msgs * sizeof(long));
 			msgs[num_msgs-1] = StrTol(MsgNum);
 		}
@@ -688,7 +697,9 @@ void groupdav_propfind(void)
 		serv_printf("MSG0 %ld|3", msgs[i]);
 		StrBuf_ServGetln(MsgNum);
 		if (GetServerStatus(MsgNum, NULL) == 1)
-			while (BufLen = StrBuf_ServGetln(MsgNum), strcmp(ChrPtr(MsgNum), "000")) 
+			while (BufLen = StrBuf_ServGetln(MsgNum), 
+			       ((BufLen >= 0) && 
+				((BufLen != 3) || strcmp(ChrPtr(MsgNum), "000")) ))
 			{
 				if (!strncasecmp(ChrPtr(MsgNum), "exti=", 5)) {
 					strcpy(uid, &ChrPtr(MsgNum)[5]);
