@@ -547,8 +547,10 @@ message_summary *ReadOneMessageSummary(StrBuf *RawMessage, const char *DefaultSu
 	Msg = (message_summary*)malloc(sizeof(message_summary));
 	memset(Msg, 0, sizeof(message_summary));
 	while (len = StrBuf_ServGetln(Buf),
+	       (len >= 0) && 
 	       ((len != 3)  ||
-		strcmp(ChrPtr(Buf), "000")== 0)){
+		strcmp(ChrPtr(Buf), "000")))
+	{
 		buf = ChrPtr(Buf);
 		ebuf = strchr(ChrPtr(Buf), '=');
 		nBuf = ebuf - buf;
@@ -599,7 +601,10 @@ int load_msg_ptrs(const char *servcmd,
 		return (Stat->nummsgs);
 	}
 	Buf2 = NewStrBuf();
-	while (len = StrBuf_ServGetln(Buf), ((len != 3) || strcmp(ChrPtr(Buf), "000")!= 0))
+	while (len = StrBuf_ServGetln(Buf), 
+	       ((len >= 0) &&
+		((len != 3) || 
+		 strcmp(ChrPtr(Buf), "000")!= 0)))
 	{
 		if (Stat->nummsgs < Stat->maxload) {
 			skipit = 0;
@@ -1233,6 +1238,7 @@ void post_message(void)
 				return;
 			}
 		}
+		FreeStrBuf(&Recp);
 		FreeStrBuf(&Buf);
 		FreeStrBuf(&Cc);
 		FreeStrBuf(&Bcc);
