@@ -31,6 +31,7 @@ typedef struct _message_summary {
 	long msgnum;		/* the message number on the citadel server */
 	int nhdr;
 	int format_type;
+	StrBuf *euid;
 	StrBuf *from;		/* the author */
 	StrBuf *to;		/* the recipient */
 	StrBuf *subj;		/* the title / subject */
@@ -59,21 +60,53 @@ typedef struct _message_summary {
 	wc_mime_attachment *MsgBody;
 } message_summary;
 void DestroyMessageSummary(void *vMsg);
-inline message_summary* GetMessagePtrAt(int n, HashList *Summ);
+
+
+
+static inline message_summary* GetMessagePtrAt(int n, HashList *Summ)
+{
+	const char *Key;
+	long HKLen;
+	void *vMsg;
+
+	if (Summ == NULL)
+		return NULL;
+	GetHashAt(Summ, n, &HKLen, &Key, &vMsg);
+	return (message_summary*) vMsg;
+}
 
 typedef void (*ExamineMsgHeaderFunc)(message_summary *Msg, StrBuf *HdrLine, StrBuf *FoundCharset);
 
 void evaluate_mime_part(message_summary *Msg, wc_mime_attachment *Mime);
 
+
+typedef enum _eCustomRoomRenderer {
+	eUseDefault = VIEW_JOURNAL + 100, 
+	eReadEUIDS
+}eCustomRoomRenderer;
+
 enum {
 	do_search,
 	headers,
 	readfwd,
 	readnew,
 	readold,
-	readgt
+	readgt,
+	readlt
 };
 
+/**
+ * @brief function to parse the | separated message headers list
+ * @param Line the raw line with your message data
+ * @param Msg put your parser results here...
+ * @param ConversionBuffer if you need some workbuffer, don't free me!
+ * @returns 0: failure, trash this message. 1: all right, store it
+ */
+typedef int (*load_msg_ptrs_detailheaders) (StrBuf *Line, 
+					    const char **pos, 
+					    message_summary *Msg, 
+					    StrBuf *ConversionBuffer);
+
 typedef void (*readloop_servcmd)(char *buf, long bufsize);
 
 typedef struct _readloopstruct {
@@ -83,8 +116,7 @@ typedef struct _readloopstruct {
 
 extern readloop_struct rlid[];
 
-
-void readloop(long oper);
+void readloop(long oper, eCustomRoomRenderer ForceRenderer);
 int read_message(StrBuf *Target, 
 		 const char *tmpl, long tmpllen, 
 		 long msgnum, 
@@ -97,25 +129,26 @@ int load_message(message_summary *Msg,
 
 
 
-typedef struct _SharedMessageStatus{
-	long load_seen;        /** should read information be loaded */
-	long sortit;           /** should we sort it using the standard sort API? */
-	long defaultsortorder; /** if we should sort it, which direction should be the default? */
+typedef struct _SharedMessageStatus {
+	long load_seen;        /* should read information be loaded */
+	long sortit;           /* should we sort it using the standard sort API? */
+	long defaultsortorder; /* if we should sort it, which direction should be the default? */
 
-	long maxload;          /** how many headers should we accept from the server? defaults to 10k */
-	long maxmsgs;          /** how many message bodies do you want to load at most?*/
-	long reverse;          /** should the load-range be reversed? */
+	long maxload;          /* how many headers should we accept from the server? defaults to 10k */
+	long maxmsgs;          /* how many message bodies do you want to load at most?*/
 
-	long startmsg;         /** which is the start message ????? */
-	long nummsgs;          /** How many messages are available to your view? */
-	long num_displayed;    /** counted up for LoadMsgFromServer */ /* TODO: unclear who should access this and why */
+	long startmsg;         /* which is the start message? */
+	long nummsgs;          /* How many messages are available to your view? */
+	long num_displayed;    /* counted up for LoadMsgFromServer */ /* TODO: unclear who should access this and why */
 
-	long lowest_found;     /** smallest Message ID found;  */
-	long highest_found;    /** highest Message ID found;  */
+	long lowest_found;     /* smallest Message ID found;  */
+	long highest_found;    /* highest Message ID found;  */
 
-}SharedMessageStatus;
+} SharedMessageStatus;
 
-int load_msg_ptrs(const char *servcmd, SharedMessageStatus *Stat);
+int load_msg_ptrs(const char *servcmd, 
+		  SharedMessageStatus *Stat, 
+		  load_msg_ptrs_detailheaders LH);
 
 typedef int (*GetParamsGetServerCall_func)(SharedMessageStatus *Stat, 
 					   void **ViewSpecific, 
@@ -161,6 +194,12 @@ void RegisterReadLoopHandlerset(
 	 */
 	PrintViewHeader_func PrintViewHeader,
 
+	/**
+	 * LH is the function, you specify if you want to load more than just message
+	 * numbers from the server during the listing fetch operation.
+	 */
+	load_msg_ptrs_detailheaders LH,
+
 	/**
 	 * LoadMsgFromServer is called for every message in the message list:
 	 *  * which is 
@@ -196,3 +235,9 @@ LoadMsgFromServer
 
 RenderView_or_Tail
 */
+
+
+int ParseMessageListHeaders_Detail(StrBuf *Line, 
+				   const char **pos, 
+				   message_summary *Msg, 
+				   StrBuf *ConversionBuffer);
