@@ -272,8 +272,10 @@ HashList *iterate_load_userlist(StrBuf *Target, WCTemplputParams *TP)
 
 		while (!Done) {
 			len = StrBuf_ServGetln(Buf);
-			if ((len == 3) &&
-			    (strcmp(ChrPtr(Buf), "000")==0)) {
+			if ((len <0) || 
+			    ((len == 3) &&
+			     !strcmp(ChrPtr(Buf), "000")))
+			{
 				Done = 1;
 				break;
 			}
